// Precompiled header used by the Entity module
#pragma once

#define DR_PRECOMPILED_INTERFACES
#define DR_PRECOMPILED_MATH

#include "precompiled_main.h"

// Some entity specifics
#include <fmt/format.h>
#include <functional>

#include "string/string.h"

#include "EntityNode.h"
